# SDRL

[![Python](https://img.shields.io/badge/python-3.8+-blue.svg)](https://www.python.org/downloads/release/python-380/) ![PyPI](https://img.shields.io/pypi/v/sdrl?color=blue) [![License](https://img.shields.io/badge/License-MIT-blue.svg)](LICENSE)

这是一个卫星数据读取的库，通过设定传感器类型可以方便的对卫星图像进行一些简单处理。持续更新中。

## 安装

```
pip install sdrl
```

## 演示

[test.ipynb](test.ipynb)
